@@ -1,6 +1,9 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <unistd.h>
+
+#include <iconv.h>
 
 
 typedef struct ITEXT{
@@ -44,4 +47,15 @@ typedef struct BOOKFILEDATA{
         struct BOOKFILEDATA *prev;
 }IBOOK_T;
 
+int ibookGetFileData(IBOOK_T **,IBOOK_T **,char *);
+
+void book_link_free(IBOOK_T **,IBOOK_T **);
+
+int itextGetTextData(char *,char *,IBUF_T **,IBUF_T **,int);
+
+int _checkFileType(char *);
+
+int itextUnZipFile(char *,char *);
+
+char * euc2utf8(iconv_t,char *,int);
 
