@@ -1,6 +1,5 @@
 #include "itext.h"
 
-#include <iconv.h>
 #include <wkf.h>
 
 static unsigned int SPACE = ' ';
@@ -12,7 +11,7 @@ static unsigned char *CHU_SMALL_STR2 = "";
 static unsigned char *CHU_SMALL_STR3 = "";
 static unsigned char *CHU_BOUTEN_STR = "˵";
 
-IBUF_T *ibuf_data_alloc()
+static IBUF_T *ibuf_data_alloc()
 {
 	IBUF_T *it;
 
@@ -25,7 +24,7 @@ IBUF_T *ibuf_data_alloc()
 
 	return it;
 }
-void ibuf_data_add(IBUF_T **start,IBUF_T **end,IBUF_T *mg)
+static void ibuf_data_add(IBUF_T **start,IBUF_T **end,IBUF_T *mg)
 {
 	if(*end){
 		mg->next = NULL;
@@ -61,7 +60,7 @@ void ibuf_data_free(IBUF_T *start,IBUF_T *end)
 
 	return;
 }
-void itext_data_free(ITEXT_T *ihead)
+static void itext_data_free(ITEXT_T *ihead)
 {
 	ITEXT_T *it,*itt;
 
@@ -75,7 +74,7 @@ void itext_data_free(ITEXT_T *ihead)
 
 	return ;
 }
-ITEXT_T *itext_data_alloc()
+static ITEXT_T *itext_data_alloc()
 {
 	ITEXT_T *it;
 
@@ -83,7 +82,7 @@ ITEXT_T *itext_data_alloc()
 	it->c1 = ' ';
 	it->c2 = ' ';
 
-	it->ej = -1;
+	it->ej = 0;
 	it->chu = 0;
 	it->bouten = 0;
 	it->small = 0;
@@ -96,7 +95,7 @@ ITEXT_T *itext_data_alloc()
 
 	return it;
 }
-void itext_data_add(ITEXT_T **start,ITEXT_T **end,ITEXT_T *mg)
+static void itext_data_add(ITEXT_T **start,ITEXT_T **end,ITEXT_T *mg)
 {
 	if(*end){
 		mg->next = NULL;
@@ -283,7 +282,7 @@ add_string :
 	}
 	return i;
 }
-int itextGetTextData(char *fname,unsigned char *title,IBUF_T **head,IBUF_T **tail)
+int itextGetTextData(char *fname,char *title,IBUF_T **head,IBUF_T **tail,int ruby_on)
 {
 	iconv_t con;
 
@@ -343,13 +342,16 @@ int itextGetTextData(char *fname,unsigned char *title,IBUF_T **head,IBUF_T **tai
 				c1 = *p++;
 				c2 = *p;
 
-				if(c1 == 0xa1 && c2 == 0xd4){ RUBI=1;continue;}
-				if(c1 == 0xa1 && c2 == 0xd5){ RUBI=0;continue;}
+				if(ruby_on){if(c1 == 0xa1 && c2 == 0xd4){ RUBI=1;continue;}} 
 
-				if(c1 == 0xa1 && c2 == 0xce && CHU == 0){
-					if(*(p+1) == 0xa1 && *(p+2) == 0xf4){
-					       	CHU = 1;
-						continue;
+				if(c1 == 0xa1 && c2 == 0xd5 && RUBI){ RUBI=0;continue;}
+
+				if(ruby_on){
+					if(c1 == 0xa1 && c2 == 0xce && CHU == 0){
+						if(*(p+1) == 0xa1 && *(p+2) == 0xf4){
+					       		CHU = 1;
+							continue;
+						}
 					}
 				}
 				if(c1 == 0xa1 && c2 == 0xcf && CHU == 1){
@@ -363,6 +365,7 @@ int itextGetTextData(char *fname,unsigned char *title,IBUF_T **head,IBUF_T **tai
 
 				if(RUBI){
 					_itext_data_insert(&itail->rubi_head,&itail->rubi_tail,c1,c2,1,0,0,con);
+
 				}else if(CHU){
 					if(itail != NULL){
 						_itext_data_insert(&itail->chu_head,&itail->chu_tail,c1,c2,1,0,0,con);
