@@ -1,3 +1,5 @@
+#include "itext.h"
+
 #include <X11/Intrinsic.h>
 #include <X11/keysym.h>
 
@@ -6,18 +8,28 @@
 #include <X11/extensions/Xrender.h>
 #endif
 
-#include <iconv.h>
-
 #ifndef __XTEXT_
 
 #define XTEXT_NAME 	"xjp-text"
-#define XTEXT_VERSION 	"0.9.5"
+#define XTEXT_VERSION 	"1.0.5"
 #define CONF_DIR_NAME 	".xtext"
 #define CONF_FILE_NAME 	"xtext.conf"
 #define SIORI_FILE_NAME "xtext.siori"
 
+#define XJP_OK  "xjp-ok"
+#define XJP_CANCEL  "xjp-cancel"
+
 #endif
 
+enum {
+	XJP_NONE = -1,
+	XJP_INT,
+	XJP_CHA,
+	XJP_STR,
+	XJP_COL,
+	XJP_FONT
+};
+
 typedef struct{
 	int main_window_width;
 	int main_window_height;
@@ -27,6 +39,9 @@ typedef struct{
 	char rubi_font_color[50];
 	char menu_window_color[50];
 	char menu_font_color[50];
+	char select_window_color[50];
+	char select_font_color[50];
+	char select_font_background_color[50];
 	char main_font_j[100];
 	char main_font_s[100];
 	char main_font_e[100];
@@ -35,6 +50,7 @@ typedef struct{
 
 	int anti;
 	int title_on;
+	int ruby_on;
 	int line_space;
 	int row_space;
 
@@ -162,9 +178,15 @@ typedef struct {
 }char_data_t;
 
 typedef struct SUBWINDOWDATA{
-	char line_str[256];
-	char re_str[256];
+	char line_str[128];
+	void *line_data;
+	char *re_str;
 
+	int (*func)();
+	void *func_data0;
+	int func_data1;
+
+	int type;
 	int line_no;
 
 	struct SUBWINDOWDATA *next;
@@ -180,6 +202,56 @@ typedef struct SIORIDATA{
 
 	struct SIORIDATA *next;
 	struct SIORIDATA *prev;
+
 }xtext_siori_t;
+typedef struct XJP_FONT_DATA {
+        char name[100];
+
+        struct XJP_FONT_DATA *head;
+        struct XJP_FONT_DATA *tail;
+
+        struct XJP_FONT_DATA *next;
+        struct XJP_FONT_DATA *prev;
+
+}xtext_font_t;
+typedef struct XJP_EFONT_DATA{
+	char name[50];
+
+	struct XJP_EFONT_DATA *next;
+	struct XJP_EFONT_DATA *prev;
+}xtext_efont_t;
 
 
+int xtext_Draw_Text(Display *,my_window_t,IBUF_T *,char_data_t,page_data_t *);
+
+int xtext_Draw_Help(Display *,my_window_t,xtext_conf_t);
+
+char * xtextSubWindow(Display *,my_window_t,sub_window_t *,sub_window_t *);
+
+int xtextSubWindow_Message(Display *,my_window_t,char *);
+
+int xtext_get_charsize(Display *,my_window_t,IBUF_T *,char_data_t *);
+
+int xtext_next_kuten(ITEXT_T *);
+
+int xtext_get_low_space(ITEXT_T *,char_data_t *);
+
+int xtextHelpData2Sub(sub_window_t **,sub_window_t **,xtext_conf_t *);
+
+int xtextSioriData2Sub(sub_window_t **,sub_window_t **,xtext_siori_t *);
+
+int xtextBookData2Sub(sub_window_t **,sub_window_t **,char *);
+
+int xtext_conf_data(xtext_conf_t *,xtext_conf_t);
+
+int xtext_conf_change(void *,int);
+
+int xtext_conf_quit(void *,int);
+
+int xtext_conf_save(void *,int);
+
+char *xtext_Selector_Window(char *,int);
+
+int xtext_font_J2E(char *,char *);
+
+int parse_xlfd_No(char *,char *,int);
