@@ -1,9 +1,8 @@
-#include "itext.h"
 #include "xtext.h"
 
 #define debug 0
 
-int XtextDrawString(	Display *disp,
+static int XtextDrawString(	Display *disp,
 			my_window_t win,
 			char_data_t char_d,
 			ITEXT_T *it,
@@ -34,7 +33,7 @@ fprintf(stderr,"END\n");
 #endif
 	return 0;
 }
-int XtextDrawAntiString(	Display *disp,
+static int XtextDrawAntiString(	Display *disp,
 				my_window_t win,
 				char_data_t char_d,
 				ITEXT_T *it,
@@ -53,16 +52,16 @@ int XtextDrawAntiString(	Display *disp,
 
 	if(it->chu) color = win.rubi_color;
 	if(it->small) font = win.font_s;
-/*
+
 	XftTextExtentsUtf8(disp,font,it->utf8,strlen(it->utf8),&gi);
 	if(it->small){
-		xoff = char_d.s_off - gi.xOff;
+		xoff = (char_d.charSize_s - gi.xOff) / 2;
 	}else{
-		xoff = char_d.m_off - gi.xOff;
+		xoff = (char_d.charSize - gi.xOff) / 2;
 	}
-	*/
+	
 
-	XftDrawStringUtf8(win.draw,&color,font,x/*+xoff*/,y,it->utf8,strlen(it->utf8));
+	XftDrawStringUtf8(win.draw,&color,font,x+xoff,y,it->utf8,strlen(it->utf8));
 #else
 
 	XtextDrawString(disp,win,char_d,it,x,y);
@@ -202,25 +201,34 @@ static int _Draw_String(	Display *disp,
 
 	return 0;
 }
-static int _get_str_size(Display *disp,my_window_t win,char *euc_str,char *utf8_str,int *w,int *h)
+static int _get_str_size(Display *disp,my_window_t win,char *euc_str,char *utf8_str,int *w,int *h,int font_type)
 {
+	XFontSet fs;
+
+	fs = win.fs_s;
+	if(font_type) fs = win.fs;
+
 	if(win.anti == 0){
 		XRectangle ink,log;
 
-		*w = XmbTextExtents(win.fs_s,euc_str,strlen(euc_str),&ink,&log) + 2;	
+		*w = XmbTextExtents(fs,euc_str,strlen(euc_str),&ink,&log) + 2;	
 		*h = log.height + 2;
 	}else{
 #if HAVE_LIBXFT
+		XftFont *font;
 		XGlyphInfo gi;
 
-		XftTextExtentsUtf8(disp,win.font_s,utf8_str,strlen(utf8_str),&gi);
+		font = win.font_s;
+		if(font_type) font = win.font;
+
+		XftTextExtentsUtf8(disp,font,utf8_str,strlen(utf8_str),&gi);
 
 		*w = gi.width;
 		*h = gi.height;
 #else
 		XRectangle ink,log;
 
-		*w = XmbTextExtents(win.fs_s,euc_str,strlen(euc_str),&ink,&log) + 2;	
+		*w = XmbTextExtents(fs,euc_str,strlen(euc_str),&ink,&log) + 2;	
 		*h = log.height + 2;
 #endif
 	}
@@ -232,12 +240,14 @@ static int _Draw_Page_Title_String(	Display *disp,
 					char *euc_str,
 					char *utf8_str,
 					int x,
-					int y		)
+					int y,
+					int font_type		)
 {
 	XFontSet fs;
 	GC gc;
 
 	fs = win.fs_s;
+	if(font_type) fs = win.fs;
 	gc = win.rubi_gc;
 
 	if(win.anti == 0){
@@ -245,7 +255,12 @@ static int _Draw_Page_Title_String(	Display *disp,
 
 	}else{
 #if HAVE_LIBXFT
-		XftDrawStringUtf8(win.draw,&(win.rubi_color),win.font_s,x,y,utf8_str,strlen(utf8_str));
+		XftFont *font;
+
+		font = win.font_s;
+		if(font_type) font = win.font;
+
+		XftDrawStringUtf8(win.draw,&(win.rubi_color),font,x,y,utf8_str,strlen(utf8_str));
 #else
 		XmbDrawString(disp,win.win,fs,gc,x,y,euc_str,strlen(euc_str));
 #endif
@@ -316,17 +331,123 @@ fprintf(stderr,"Draw END\n");
 
 _draw_end:
 	sprintf(page_str,"(%d/%d)",char_p->page_no,char_d.book->total_page);
-	_get_str_size(disp,win,page_str,page_str,&width,&height);
-	_Draw_Page_Title_String(disp,win,page_str,page_str,(win.width-width)/2,win.height-2);
+	_get_str_size(disp,win,page_str,page_str,&width,&height,0);
+	_Draw_Page_Title_String(disp,win,page_str,page_str,(win.width-width)/2,win.height-2,0);
 
 	if(win.title_on){
-		_get_str_size(disp,win,char_d.book->book_title,char_d.book->book_title_utf8,&width,&height);
-		_Draw_Page_Title_String(disp,win,char_d.book->book_title,char_d.book->book_title_utf8,2,height);
+		_get_str_size(disp,win,char_d.book->book_title,char_d.book->book_title_utf8,&width,&height,0);
+		_Draw_Page_Title_String(disp,win,char_d.book->book_title,char_d.book->book_title_utf8,2,height,0);
 	}
 
 
 	return char_p->char_no;
 }
+int xtext_Draw_Help(Display *disp,my_window_t win,xtext_conf_t xconf)
+{
+	iconv_t con;
+	char *help_str = NULL,*help_utf8 = NULL;
+	int x0,y0,width,height;
+	int font_type;
+
+	con = iconv_open("UTF-8","EUC-JP");
+	help_str = (char *)malloc(256);
+
+	font_type = 1;
+	sprintf(help_str,"%s   Ver. %s",XTEXT_NAME,XTEXT_VERSION);
+	_get_str_size(disp,win,help_str,help_str,&width,&height,font_type);
+	x0 = (win.width - width) / 2;
+	y0 = height + 10;
+	_Draw_Page_Title_String(disp,win,help_str,help_str,x0,y0,font_type);
+
+	font_type = 0;
+	strcpy(help_str,"Creater : aFterbrEaK");
+	_get_str_size(disp,win,help_str,help_str,&width,&height,font_type);
+	x0 = (win.width - width) / 2;
+	y0 = y0 + height + 10;
+	_Draw_Page_Title_String(disp,win,help_str,help_str,x0,y0,font_type);
+
+	strcpy(help_str,"HomePage : http://xjp-text.sourceforge.jp/");
+	_get_str_size(disp,win,help_str,help_str,&width,&height,font_type);
+	x0 = (win.width - width) / 2;
+	y0 = y0 + height + 5;
+	_Draw_Page_Title_String(disp,win,help_str,help_str,x0,y0,font_type);
+
+	strcpy(help_str,"E-Mail : afterbreak@users.sourceforge.jp");
+	_get_str_size(disp,win,help_str,help_str,&width,&height,font_type);
+	x0 = x0;
+	y0 = y0 + height + 5;
+	_Draw_Page_Title_String(disp,win,help_str,help_str,x0,y0,font_type);
+
+
+	font_type = 1;
+	strcpy(help_str," ˡ ");
+	help_utf8 = (char *)euc2utf8(con,help_str,strlen(help_str));
+	_get_str_size(disp,win,help_str,help_utf8,&width,&height,font_type);
+	x0 = 10;
+	y0 = y0 + height + 20;
+	_Draw_Page_Title_String(disp,win,help_str,help_utf8,x0,y0,font_type);
+	if(help_utf8) free(help_utf8);
+
+	font_type = 0;
+	sprintf(help_str,"*޽::' %s '  *::' %s '  *ǧ::' %s '",xconf.menu,xconf.siori_menu,xconf.conf_page);
+	help_utf8 = (char *)euc2utf8(con,help_str,strlen(help_str));
+	_get_str_size(disp,win,help_str,help_utf8,&width,&height,font_type);
+	x0 = 10;
+	y0 = y0 + height + 10;
+	_Draw_Page_Title_String(disp,win,help_str,help_utf8,x0,y0,font_type);
+	if(help_utf8) free(help_utf8);
+
+	sprintf(help_str,"*ڡ::' %s '  *ڡ::' %s '  *XJP-TEXTλ::' %s '",xconf.page_next,xconf.page_prev,xconf.quit);
+	help_utf8 = (char *)euc2utf8(con,help_str,strlen(help_str));
+	_get_str_size(disp,win,help_str,help_utf8,&width,&height,font_type);
+	x0 = 10;
+	y0 = y0 + height + 5;
+	_Draw_Page_Title_String(disp,win,help_str,help_utf8,x0,y0,font_type);
+	if(help_utf8) free(help_utf8);
+
+	sprintf(help_str,"*(֥åޡ)::' %s '   *ȥɽON-OFF::' %s '",xconf.book_mark,xconf.title_key);
+	help_utf8 = (char *)euc2utf8(con,help_str,strlen(help_str));
+	_get_str_size(disp,win,help_str,help_utf8,&width,&height,font_type);
+	x0 = 10;
+	y0 = y0 + height + 5;
+	_Draw_Page_Title_String(disp,win,help_str,help_utf8,x0,y0,font_type);
+	if(help_utf8) free(help_utf8);
+
+	sprintf(help_str,"*޽¸DIR::' %s '",xconf.book_dir);
+	help_utf8 = (char *)euc2utf8(con,help_str,strlen(help_str));
+	_get_str_size(disp,win,help_str,help_utf8,&width,&height,font_type);
+	x0 = 10;
+	y0 = y0 + height + 5;
+	_Draw_Page_Title_String(disp,win,help_str,help_utf8,x0,y0,font_type);
+	if(help_utf8) free(help_utf8);
+
+	font_type = 1;
+	strcpy(help_str,"ޤϡ޽̤顢ɤ");
+	help_utf8 = (char *)euc2utf8(con,help_str,strlen(help_str));
+	_get_str_size(disp,win,help_str,help_utf8,&width,&height,font_type);
+	x0 = (win.width - width) / 2;
+	y0 = y0 + height + 40;
+	_Draw_Page_Title_String(disp,win,help_str,help_utf8,x0,y0,font_type);
+	if(help_utf8) free(help_utf8);
+
+	font_type = 0;
+	strcpy(help_str,"޽̤ϡĤǤƤӽФȤޤ");
+	help_utf8 = (char *)euc2utf8(con,help_str,strlen(help_str));
+	_get_str_size(disp,win,help_str,help_utf8,&width,&height,font_type);
+	x0 = (win.width - width) / 2;
+	y0 = y0 + height + 10;
+	_Draw_Page_Title_String(disp,win,help_str,help_utf8,x0,y0,font_type);
+	if(help_utf8) free(help_utf8);
+
+
+
+	if(help_str) free(help_str);
+	iconv_close(con);
+	return 0;
+}
+
+
+
 
 			
 
