@@ -1,8 +1,5 @@
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <unistd.h>
-#include <iconv.h>
+#include "itext.h"
+
 
 char * euc2utf8(iconv_t con,char *str,int len)
 {
